
import feedparser
import argparse
import json
import pycurl
import subprocess
from pathlib import Path
import traceback


def download_audio(link, destdir):
    parts = link.split('/')
    ptarget = Path(destdir) / Path(parts[-1])
    target = ptarget.resolve()
    if target.exists():
        print("File already exists, skipping")
    else:
        with open(target, "wb") as fp:
            curl = pycurl.Curl()
            curl.setopt(pycurl.URL, link)
            curl.setopt(pycurl.FOLLOWLOCATION, 1)
            curl.setopt(pycurl.MAXREDIRS, 5)
            curl.setopt(pycurl.CONNECTTIMEOUT, 30)
            curl.setopt(pycurl.TIMEOUT, 300)
            curl.setopt(pycurl.NOSIGNAL, 1)
            curl.setopt(pycurl.WRITEDATA, fp)
            try:
                curl.perform()
            except:
                traceback.print_exc(file=sys.stderr)
                sys.stderr.flush()
            curl.close()



def looks_audio(link):
    if 'type' in link:
        return link['type'][:5] == 'audio'
    return False


def get_latest(url, dir):
    d = feedparser.parse(url)
    title = d.feed.get('title', "[no title]")
    entries = d.get('entries', [])
    if entries:
        latest = entries[0]
        if 'links' in latest:
            sounds = [ l for l in latest['links'] if looks_audio(l) ]
            if len(sounds) < 0:
                print("No audio links")
            if len(sounds) > 1:
                print("Multiple audio links")
            for s in sounds:
                audio_url = s.get('href', '')
                if audio_url:
                    return audio_url
    return None

def main():
    ap = argparse.ArgumentParser("autoradio - download audio from RSS feeds")
    ap.add_argument(
        "--config",
        default="./config.json",
        type=Path,
        help="Config file",
    )
    args = ap.parse_args()
    with open(args.config, 'r') as cfh:
        cf = json.load(cfh)
        for name, config in cf['feeds'].items():
            print(f"Checking {name}")
            url = get_latest(config['url'], config['dir'])
            if url:
                print(f"content = {url}")
                download_audio(url, config['dir'])

